@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "poly-markdown" "0.2.2"
+(define-package "poly-markdown" "20251101.1318"
   "Polymode for markdown-mode."
   '((emacs         "25")
     (polymode      "0.2.2")
     (markdown-mode "2.3"))
   :url "https://github.com/polymode/poly-markdown"
-  :commit "1536cf0c32f71d5cd05c90f7905905e38006e95d"
-  :revdesc "1536cf0c32f7"
+  :commit "2eb00d1d07a9dd5d94c5c12c27714e095b3b142a"
+  :revdesc "2eb00d1d07a9"
   :keywords '("emacs"))
